@@ -1,12 +1,12 @@
-import importlib.metadata
 from dataclasses import dataclass, field
-from typing import Callable, Optional, Type, TypeVar
+from typing import Any, Callable, Optional, Type, TypeVar
 
-from omegaconf import II, MISSING, SI, DictConfig, ListConfig
+from omegaconf import MISSING, DictConfig, ListConfig
 
 from .commandline import cli
 from .core import (
     cast,
+    edit_list,
     from_dataclass,
     from_dict,
     from_file,
@@ -14,31 +14,27 @@ from .core import (
     from_options,
     from_string,
     merge,
+    resolve,
     to_dict,
     to_yaml,
+    unsafe_merge,
     validate,
 )
-from .flexyclasses import flexy_field, flexyclass, make_flexy
+from .flexyclasses import flexyclass
 from .initialize import Target, init
 from .logging import configure_logging
 from .nicknames import NicknameRegistry
 from .resolvers import all_resolvers, register
 from .traversal import traverse
 from .types import get_type
-from .utils import SpringsWarnings
+from .utils import SpringsWarnings, get_version
+
+__version__ = get_version()
+
 
 T = TypeVar("T")
 
 
-try:
-    # package has been installed, so it has a version number
-    # from pyproject.toml
-    __version__ = importlib.metadata.version(__package__ or __name__)
-except importlib.metadata.PackageNotFoundError:
-    # package hasn't been installed, so set version to "dev"
-    __version__ = "dev"
-
-
 def toggle_warnings(value: Optional[bool] = None):
     """Shortcut for springs.utils.SpringsWarnings.toggle"""
     SpringsWarnings.toggle(value)
@@ -54,6 +50,16 @@ def nickname(name: str) -> Callable[[Type[T]], Type[T]]:
     return NicknameRegistry.add(name)
 
 
+def make_flexy(cls_: Any) -> Any:
+    """Shortcut for springs.flexyclasses.flexyclass"""
+
+    SpringsWarnings.deprecated(
+        deprecated="make_flexy",
+        replacement="flexyclass",
+    )
+    return flexyclass(cls_)
+
+
 __all__ = [
     "all_resolvers",
     "cast",
@@ -61,8 +67,8 @@ __all__ = [
     "configure_logging",
     "dataclass",
     "DictConfig",
+    "edit_list",
     "field",
-    "flexy_field",
     "flexyclass",
     "from_dataclass",
     "from_dict",
@@ -71,7 +77,6 @@ __all__ = [
     "from_options",
     "from_string",
     "get_type",
-    "II",
     "init",
     "ListConfig",
     "make_flexy",
@@ -80,11 +85,12 @@ __all__ = [
     "MISSING",
     "nickname",
     "register",
-    "SI",
+    "resolve",
     "Target",
     "to_dict",
     "to_yaml",
     "toggle_warnings",
     "traverse",
+    "unsafe_merge",
     "validate",
 ]
